/************************************************************************/
/*                                                                      */
/*  PmodRS485 MPIDE Demo                                                */
/*                                                                      */
/************************************************************************/
/*  Author: Marshall Wingerson                                          */
/*  Copyright 2014, Digilent Inc.                                       */
/************************************************************************/
/*  Module Description:                                                 */
/*    This is a simple loopback demo for the RS485 pmod. The pmod       */
/*    needs to be plugged into the upper row of the JH pmod header of   */
/*    the MX4cK microcontroller and terminals need to be connected with */
/*    wires (Y=>A) and (Z=>B).                                          */
/*                                                                      */
/*    For the demo open the serial monitor and send strings to the      */
/*    microcontroller.                                                  */
/*                                                                      */
/*                                                                      */
/************************************************************************/
/*  Revision History:                                                   */
/*                                                                      */
/*  06/27/2014 (MarshallW): created                                     */
/*                                                                      */
/************************************************************************/

#define bufferSize 120

//define the enable pins
const int RXD_Enable = 48;
const int TXD_Enable = 51;

String tempString;
String nullString;

char buffer[bufferSize];
char *bufferPtr;

void setup()
{
  Serial.begin(115200);
  Serial1.begin(115200);
  pinMode(RXD_Enable, OUTPUT);
  pinMode(TXD_Enable, OUTPUT);
  digitalWrite(RXD_Enable, LOW);
  digitalWrite(TXD_Enable, HIGH);
 
  nullString = String();
 
  Serial.println("------------------");
  Serial.println("--PmodRS485 Demo--");
  Serial.println("------------------\n");
}

void loop()
{
	bufferPtr = buffer;
	tempString = String();
	
	//read from PC serial 
	while(Serial.available() > 0)
	{
		*bufferPtr = (char)Serial.read();
		bufferPtr++;
		delay(1);  
	}
	
	//convert the char array into String object
	//to demonstrate the String object
	if(buffer != bufferPtr)
	{
		tempString = String(buffer);
	}
	
	//clear the buffer
	clearbuffer();

	//reset bufferPtr to the beginning of the buffer
	bufferPtr = buffer;
	
	//print to Serial1 that is attached to the PmodRS485
	Serial1.print(tempString);
	
	delay(5);
	
	//read from Pmod Serial1 loopback
	while(Serial1.available() > 0)
	{
		*bufferPtr = (char)Serial1.read();
		bufferPtr++;
		delay(1);  
	}
  	
	//convert the char array into String object
	//to demonstrate the String object
	if(buffer != bufferPtr)
	{
		tempString = String(buffer);
	}
	
	//clear the buffer
	clearbuffer();
	
	if(tempString != nullString)
	{	
		Serial.print("You typed: ");
		Serial.println(tempString);
	}
	
	delay(10);
}


//Just sets all values in the buffer to 0
bool clearbuffer(){

	bufferPtr = buffer;
	for(int i = 0; i < bufferSize; i++)
	{	
		*bufferPtr = 0;
		bufferPtr++;
	}

}
